@@ -48,6 +48,7 @@
 #include "as_gfx/statok.xpm"    // static const char *s_kpcStatokay_xpm[]
 #include "as_gfx/staterr.xpm"   // static const char *s_kpcStaterror_xpm[]
 #include "as_gfx/statwrn.xpm"   // static const char *s_kpcStatwarn_xpm[]
+#include "as_gfx/statvoid.xpm"  // static const char *s_kpcStatvoid_xpm[]
 
 
 //
@@ -85,9 +86,6 @@ void Titraqform::pasteEntry(void)
     QString Selection;          // Will receive the clipboard text
     QClipboard *pClip;          // Will reference the global clipboard
 
-    // Optimize viewing by repainting cells only once after processing
-    m_pMaintable->setUpdatesEnabled(false);
-
     if (Selection = pClip->text(QClipboard::Clipboard)) { // Windows and Unix
         nRows = Selection.contains(QChar('\n'));    // How many rows
         this->addEntry(nRows);                      // Reuse slot
@@ -101,8 +99,6 @@ void Titraqform::pasteEntry(void)
         for (int nIter = 0; nIter < nRows; nIter++)
             this->validateData(m_pMaintable->currentRow() + nIter, 0);
     }
-
-    m_pMaintable->setUpdatesEnabled(true);          // Update and repaint
 }
 
 //
@@ -182,8 +178,8 @@ void Titraqform::addEntry(int nRows)
 //    uuid_unparse(Guid, szGuitext);
 //    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXGUID, szGuitext);
 
-    m_pMaintable->setUpdatesEnabled(true);          // Turn updates back on
-    m_pMaintable->repaintContents(false);           // Repaint viewport
+    m_pMaintable->setUpdatesEnabled(true);  // Turn updates back on
+    m_pMaintable->repaintContents(true);    // Do a general repaint of table
 }
 
 //
@@ -231,7 +227,7 @@ void Titraqform::refreshDisplay(void)
         nIter++;
     }
 
-    m_pMaintable->repaintContents(true);    // Do a general repaint of table
+    m_pMaintable->repaintContents(false);   // Do a general repaint of table
     m_pStatbar->message(trUtf8("Display was refreshed"), 4000); // Announce result
 }
 
@@ -251,77 +247,29 @@ void Titraqform::newDoc(void)
         switch (nResult) {
         case 0: // First button selected, so save first
             this->saveFile();               // Save changes first
-
-            // Reset widget text values before blanking table
-            m_pDateedit->setDate(*m_pDatezero);
-            m_pStarttime->setTime(QTime::QTime(0, 0));
-            m_pEndtime->setTime(QTime::QTime(0, 0));
-            m_pAmount->setText(NULL);
-            m_pTasks->setCurrentText(NULL);
-            m_pRemark->setText(NULL);
-
-            m_pMaintable->setEnabled(true); // Enable the table first
-            m_pMaintable->setNumRows(0);    // Remove all data in table
-            m_pLineedit->setEnabled(true);
-            m_pUseredit->setEnabled(true);
-            m_pGuidedit->setEnabled(true);
-            m_pCrcedit->setEnabled(true);
-            m_pRevedit->setEnabled(true);
-            m_pDateedit->setEnabled(true);
-            m_pStarttime->setEnabled(true);
-            m_pEndtime->setEnabled(true);
-            m_pAmount->setEnabled(true);
-            m_pTasks->setEnabled(true);
-            m_pRemark->setEnabled(true);
-            this->updEdit(0, 0);            // Reset edit controls
-            m_pMaintable->setDirty(false);  // Reset data to clean state
             break;
-        case 1: // Second button selected, so don't save first but do new
-            m_pMaintable->setEnabled(true); // Enable the table first
-            m_pMaintable->setNumRows(0);    // Remove all data in table
-            m_pLineedit->setEnabled(true);
-            m_pUseredit->setEnabled(true);
-            m_pGuidedit->setEnabled(true);
-            m_pCrcedit->setEnabled(true);
-            m_pRevedit->setEnabled(true);
-            m_pDateedit->setEnabled(true);
-            m_pStarttime->setEnabled(true);
-            m_pEndtime->setEnabled(true);
-            m_pAmount->setEnabled(true);
-            m_pTasks->setEnabled(true);
-            m_pRemark->setEnabled(true);
-            this->updEdit(0, 0);            // Reset edit controls
-            m_pMaintable->setDirty(false);  // Reset data to clean state
+        case 1: // Second button selected, so don't save
             break;
-        case 2: // Third button selected, so don't do a new timesheet
+        case 2: // Third button selected, so return sofort
         default:
+            return;
             break;
         }
     }
-    else { // Data is already up to date
-        // Reset widget text values before blanking table
-        m_pDateedit->setDate(*m_pDatezero);
-        m_pStarttime->setTime(QTime::QTime(0, 0));
-        m_pEndtime->setTime(QTime::QTime(0, 0));
-        m_pAmount->setText(NULL);
-        m_pTasks->setCurrentText(NULL);
-        m_pRemark->setText(NULL);
-        m_pMaintable->setEnabled(true);     // Enable the table first
-        m_pMaintable->setNumRows(0);        // Remove all data in table
-        m_pLineedit->setEnabled(true);
-        m_pUseredit->setEnabled(true);
-        m_pGuidedit->setEnabled(true);
-        m_pCrcedit->setEnabled(true);
-        m_pRevedit->setEnabled(true);
-        m_pDateedit->setEnabled(true);
-        m_pStarttime->setEnabled(true);
-        m_pEndtime->setEnabled(true);
-        m_pAmount->setEnabled(true);
-        m_pTasks->setEnabled(true);
-        m_pRemark->setEnabled(true);
-        this->updEdit(0, 0);                // Reset edit controls
-        m_pMaintable->setDirty(false);      // Reset data to clean state
-    }
+    // Fall through to implicit new doc code
+    this->enableIface(true);            // Enable the interface
+    m_pMaintable->setNumRows(0);        // Remove all data in table
+    this->setCaption(trUtf8("No file name"));
+    m_pStatbar->message(trUtf8("New document"), 4000);
+    this->setFilename("");
+
+    // Reset widget text of edit controls
+    m_pDateedit->setDate(*m_pDatezero);
+    m_pStarttime->setTime(QTime::QTime(0, 0));
+    m_pEndtime->setTime(QTime::QTime(0, 0));
+    m_pAmount->setText(NULL);
+    m_pTasks->setCurrentText(NULL);
+    m_pRemark->setText(NULL);
 }
 
 //
@@ -343,7 +291,7 @@ void Titraqform::openDoc(void)
             switch (nResult) {
             case 0: // Save first
                 this->saveFile();               // Save changes first
-                m_szFilename->operator=(Filestring);
+                setFilename(Filestring);        // Set the new file name
                 m_pMaintable->setNumRows(0);    // Clear out old data
                 try {
                     loadData(Filetemp);         // Pass to helper method
@@ -351,25 +299,9 @@ void Titraqform::openDoc(void)
                 catch (Genexcept& Genex) {
                     Genex.reportErr();
                 }
-                // Reset and give output to main window
-                this->setCaption(Filestring);
-                m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
-                m_pMaintable->setEnabled(true); // Enable the table first
-                m_pLineedit->setEnabled(true);
-                m_pUseredit->setEnabled(true);
-                m_pGuidedit->setEnabled(true);
-                m_pCrcedit->setEnabled(true);
-                m_pRevedit->setEnabled(true);
-                m_pDateedit->setEnabled(true);
-                m_pStarttime->setEnabled(true);
-                m_pEndtime->setEnabled(true);
-                m_pAmount->setEnabled(true);
-                m_pTasks->setEnabled(true);
-                m_pRemark->setEnabled(true);
-                m_pMaintable->setDirty(false);  // Set the clean state
                 break;
             case 1: // Don't save first but do load
-                m_szFilename->operator=(Filestring);
+                setFilename(Filestring);        // Set the new file name
                 m_pMaintable->setNumRows(0);    // Clear out old data
                 try {
                     loadData(Filetemp);         // Pass to helper method
@@ -377,22 +309,6 @@ void Titraqform::openDoc(void)
                 catch (Genexcept& Genex) {
                     Genex.reportErr();
                 }
-                // Reset and give output to main window
-                this->setCaption(Filestring);
-                m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
-                m_pMaintable->setEnabled(true); // Enable the table first
-                m_pLineedit->setEnabled(true);
-                m_pUseredit->setEnabled(true);
-                m_pGuidedit->setEnabled(true);
-                m_pCrcedit->setEnabled(true);
-                m_pRevedit->setEnabled(true);
-                m_pDateedit->setEnabled(true);
-                m_pStarttime->setEnabled(true);
-                m_pEndtime->setEnabled(true);
-                m_pAmount->setEnabled(true);
-                m_pTasks->setEnabled(true);
-                m_pRemark->setEnabled(true);
-                m_pMaintable->setDirty(false);  // Set the clean state
                 break;
             case 2: // Don't do a load timesheet
             default:
@@ -400,31 +316,20 @@ void Titraqform::openDoc(void)
             }
         }
         else {
-            m_szFilename->operator=(Filestring);
-            m_pMaintable->setNumRows(0);    // Clear out old data
+            setFilename(Filestring);            // Set the new file name
+            m_pMaintable->setNumRows(0);        // Clear out old data
             try {
-                loadData(Filetemp);         // Pass to helper method
+                loadData(Filetemp);             // Pass to helper method
             }
             catch (Genexcept& Genex) {
                 Genex.reportErr();
             }
-            // Reset and give output to main window
-            this->setCaption(Filestring);
-            m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
-            m_pMaintable->setEnabled(true); // Enable the table first
-            m_pLineedit->setEnabled(true);
-            m_pUseredit->setEnabled(true);
-            m_pGuidedit->setEnabled(true);
-            m_pCrcedit->setEnabled(true);
-            m_pRevedit->setEnabled(true);
-            m_pDateedit->setEnabled(true);
-            m_pStarttime->setEnabled(true);
-            m_pEndtime->setEnabled(true);
-            m_pAmount->setEnabled(true);
-            m_pTasks->setEnabled(true);
-            m_pRemark->setEnabled(true);
-            m_pMaintable->setDirty(false);  // Set the clean state
         }
+
+        // Fall through to implicit open code
+        this->setCaption(Filestring);
+        m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+        this->enableIface(true);    // Turn on the lights
     }
     else
         m_pStatbar->message(trUtf8("Loading aborted"), 4000);
@@ -435,23 +340,24 @@ void Titraqform::openDoc(void)
 //
 void Titraqform::saveFile(void)
 {
-    // First time saves are really just saveAs in disguise
-    if (m_szFilename->isEmpty()) {
-        saveAs();
-        return;
-    }
-
-    // Try to open a file for writing to
-    QFile Filetemp(*m_szFilename);
+    QString Fname;
     try {
-        saveData(Filetemp); // Pass to helper method
+        Fname = QString(*this->getFilename());
+        // First time saves are really just saveAs in disguise
+        if (Fname.isEmpty()) {
+            this->saveAs();
+            return;
+        }
+        // Try to open a file for writing to
+        QFile Filetemp(Fname);
+        this->saveData(Filetemp); // Pass to helper method
     }
     catch (Genexcept& Genex) {
         Genex.reportErr();
     }
     // Reset and give output to main window
-    this->setCaption(*m_szFilename);
-    m_pStatbar->message(trUtf8("File %1 saved").arg(*m_szFilename), 4000);
+    this->setCaption(Fname);
+    m_pStatbar->message(trUtf8("File %1 saved").arg(Fname), 4000);
     m_pMaintable->setDirty(false);  // Set the clean state to allow close
 }
 
@@ -463,15 +369,14 @@ void Titraqform::saveAs(void)
     int nResult = 0; // For checking user's answer
 
     // First get the selected file name to save to
-    QString Filestring =
-    QFileDialog::getSaveFileName(m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE), trUtf8("Accounting Data (*.as);;Text files (*.txt);;All Files (*)"), this, trUtf8("ChooserDialog"), trUtf8("Choose a file to save"), NULL, false);
+    QString Filestring = QFileDialog::getSaveFileName(m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE), trUtf8("Accounting Data (*.as);;Text files (*.txt);;All Files (*)"), this, trUtf8("ChooserDialog"), trUtf8("Choose a file to save"), NULL, false);
     if (!Filestring.isEmpty()) {
-        *m_szFilename = Filestring;
-        if (QFile::exists(*m_szFilename)) {
+        if (QFile::exists(Filestring)) {
             nResult = QMessageBox::warning(this, trUtf8(TITRAQ_APPTITLE),
                       trUtf8(TITRAQ_OVERWRITE), trUtf8("&Yes"), trUtf8("&No"), NULL, 1, 1);
             switch (nResult) {
             case 0: // Overwrite contents
+                this->setFilename(Filestring);
                 this->saveFile();
                 break;
             case 1: // Don't overwrite
@@ -495,32 +400,33 @@ void Titraqform::closeEvent(QCloseEvent *pClosit)
 {
     int nResult = 0;
 
+    if (!this->isOpen())    // Short circuit if user
+        qApp->quit();       // selects close twice
+
     // Check modification state of current data
     if (m_pMaintable->isDirty()) {
         nResult = QMessageBox::information(this, trUtf8(TITRAQ_APPTITLE),
                   trUtf8(TITRAQ_SAVEFIRST), trUtf8("&Save"),
                   trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
 
-        switch (nResult) {
+        switch (nResult) {      // Maybe save before closing
         case 0: // Save first
-            this->saveFile();               // Save changes first
-            m_pMaintable->setDirty(false);  // Reset data to clean state
-            pClosit->accept();              // then close timesheet
+            this->saveFile();   // Save changes first
             break;
-        case 1: // Don't save first but close
-            m_pMaintable->setDirty(false);  // Reset data to clean state
-            pClosit->accept();              // Close timesheet
+        case 1: // Don't save first
             break;
-        case 2: // Don't close
+        case 2: // Do nothing
         default:
             pClosit->ignore();
+            return; // Go away without closing
             break;
         }
     }
-    else {                                  // Data is already up to date
-        m_pMaintable->setDirty(false);      // Reset data to clean state
-        pClosit->accept();
-    }
+
+    // Fall through to implicit close code
+    this->enableIface(false);   // Turn off the lights
+    this->setOpen(false);       // Set doc state to closed
+    pClosit->ignore();          // Finish off by not closing
 }
 
 //
@@ -689,7 +595,10 @@ void Titraqform::updEdit(int nRow, int nCol)
     m_pMaintable->setEdition();
 
     // Set text of member edit controls
-    m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, TITRAQ_IDXSTATUS));
+    if (m_pMaintable->text(nRow, TITRAQ_IDXSTATUS).isEmpty())   // If row is empty
+        m_pStatusedit->setPixmap(s_kpcStatvoid_xpm);            // add a placeholder
+    else
+        m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, TITRAQ_IDXSTATUS));
     m_pLineedit->setText(Textline);
     m_pUseredit->setText(Textuser);
     m_pGuidedit->setText(Textguid);
@@ -740,7 +649,8 @@ void Titraqform::validateData(int nRow, int nCol)
         m_pMaintable->text(nRow, TITRAQ_IDXTASK).isEmpty())
     { // No K&R style to show where actual code begins
         if (Statis.startsWith(QString("W"))) { // Conditionally set pixmap to avoid overhead
-            m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, TITRAQ_IDXSTATUS));
+// FIXME: Next line commented out, and I see that this algorythm needs help
+//            m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, TITRAQ_IDXSTATUS));
         }
         else if (!Statis.startsWith(QString("E"))) { // Conditionally set pixmap to avoid overhead
             m_pMaintable->setText(nRow, TITRAQ_IDXSTATUS, Statis.replace(TITRAQ_IDXSTATERROR, sizeof(char), 'E'));
